pub enum Cap {
Butt,
Round,
Square,
}Expand description
Cap determines how a stroke ends at an open contour.
Variants
Butt
Butt ends the stroke at the endpoint.
Round
Round extends the stroke with a semicircle.
Square
Square extends the stroke by half its width with a square edge.